@@ -50,6 +50,8 @@ class VkontakteAccessToken(BaseAccessToken):
         '''
         Parse page with permissions form and return tuple with (method, form action, form submit parameters)
         '''
+        print page_content.decode('windows-1251')
+
         matches = re.findall('location.href = "([^"]+https=1)"', page_content)
         if len(matches) != 1:
             log.error("Error while parsing permissions page contents: %s" % page_content)
@@ -62,6 +64,7 @@ class VkontakteAccessToken(BaseAccessToken):
         Protection from security question about end of phone number
         '''
         response = super(VkontakteAccessToken, self).authorize()
+        print response.content.decode('windows-1251')
 
         # login from new place
         if response.content == 'security breach':
@@ -85,6 +88,13 @@ class VkontakteAccessToken(BaseAccessToken):
             form = content.find('form')
             response = requests.get(form['action'], cookies=response.cookies)
 
+        # other grant access questions
+        elif 'https://login.vk.com/?act=grant_access' in response.content:
+            for url in re.findall(r'"(https:\/\/login.vk.com\/\?act=grant_access[^"]+)"', response.content):
+                if 'cancel' not in url:
+                    response = requests.get(url, cookies=response.cookies)
+                    break
+
         if 'class="oauth_error"' in response.content:
             content = BeautifulSoup(response.content.decode('windows-1251'))
             raise OAuthError(content.find('div', **{'class': 'oauth_error'}).text.encode('utf-8'))
